@@ -8,7 +8,8 @@ use self::compress::{
     easing_function::compress_easing_function, empty::compress_empty,
     frequency::compress_frequency, keyframes::compress_keyframes, length::compress_length,
     selector::compress_selector, time::compress_time,
-    transform_function::compress_transform_function, urange::compress_urange, url::compress_url,
+    transform_function::compress_transform_function, unicore_range::compress_unicode_range,
+    url::compress_url,
 };
 
 mod compress;
@@ -21,7 +22,7 @@ pub fn minify(stylesheet: &mut Stylesheet) {
     stylesheet.visit_mut_with(&mut compress_time());
     stylesheet.visit_mut_with(&mut compress_frequency());
     stylesheet.visit_mut_with(&mut compress_url());
-    stylesheet.visit_mut_with(&mut compress_urange());
+    stylesheet.visit_mut_with(&mut compress_unicode_range());
     stylesheet.visit_mut_with(&mut compress_easing_function());
     stylesheet.visit_mut_with(&mut compress_transform_function());
     stylesheet.visit_mut_with(&mut compress_declaration());
